# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'InstanceDataDiskArgs',
    'InstanceSystemDiskArgs',
]

@pulumi.input_type
class InstanceDataDiskArgs:
    def __init__(__self__, *,
                 category: Optional[pulumi.Input[str]] = None,
                 size: Optional[pulumi.Input[int]] = None):
        """
        :param pulumi.Input[str] category: Type of dataDisk
               - cloud_efficiency：High-efficiency cloud disk
               - cloud_ssd：Full flash cloud disk
               - local_hdd：Local hdd disk
               - local_ssd：Local disk ssd.
        :param pulumi.Input[int] size: Data disk size, cloud_efficiency is 20-32000,cloud_ssd/local_hdd/local_ssd is 20-25000, unit: GB.
        """
        if category is not None:
            pulumi.set(__self__, "category", category)
        if size is not None:
            pulumi.set(__self__, "size", size)

    @property
    @pulumi.getter
    def category(self) -> Optional[pulumi.Input[str]]:
        """
        Type of dataDisk
        - cloud_efficiency：High-efficiency cloud disk
        - cloud_ssd：Full flash cloud disk
        - local_hdd：Local hdd disk
        - local_ssd：Local disk ssd.
        """
        return pulumi.get(self, "category")

    @category.setter
    def category(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "category", value)

    @property
    @pulumi.getter
    def size(self) -> Optional[pulumi.Input[int]]:
        """
        Data disk size, cloud_efficiency is 20-32000,cloud_ssd/local_hdd/local_ssd is 20-25000, unit: GB.
        """
        return pulumi.get(self, "size")

    @size.setter
    def size(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "size", value)


@pulumi.input_type
class InstanceSystemDiskArgs:
    def __init__(__self__, *,
                 size: Optional[pulumi.Input[int]] = None):
        """
        :param pulumi.Input[int] size: System disk size, cloud_efficiency is 20-32000,cloud_ssd/local_hdd/local_ssd is 20-25000, unit: GB.
        """
        if size is not None:
            pulumi.set(__self__, "size", size)

    @property
    @pulumi.getter
    def size(self) -> Optional[pulumi.Input[int]]:
        """
        System disk size, cloud_efficiency is 20-32000,cloud_ssd/local_hdd/local_ssd is 20-25000, unit: GB.
        """
        return pulumi.get(self, "size")

    @size.setter
    def size(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "size", value)





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = ['InstanceArgs', 'Instance']

@pulumi.input_type
class InstanceArgs:
    def __init__(__self__, *,
                 instance_class: pulumi.Input[str],
                 instance_storage: pulumi.Input[str],
                 payment_type: pulumi.Input[str],
                 vswitch_id: pulumi.Input[str],
                 app_key: Optional[pulumi.Input[str]] = None,
                 disk_category: Optional[pulumi.Input[str]] = None,
                 duration: Optional[pulumi.Input[str]] = None,
                 engine_type: Optional[pulumi.Input[str]] = None,
                 instance_alias: Optional[pulumi.Input[str]] = None,
                 zone_id: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a Instance resource.
        :param pulumi.Input[str] instance_class: The specification of the instance. 
               - Following enumerative value for TSDB for InfluxDB️ standart edition:
               - `influxdata.n1.mxlarge` refers to 2 CPU 8GB memory;
               - `influxdata.n1.xlarge` refers to 4 CPU 16GB memory;
               - `influxdata.n1.2xlarge` refers to 8 CPU 32 GB memory;
               - `influxdata.n1.4xlarge` refers to 16 CPU 64 GB memory;
               - `influxdata.n1.8xlarge` refers to 32 CPU 128 GB memory;
               - `influxdata.n1.16xlarge` refers to 64 CPU 256 GB memory.
               - Following enumerative value for TSDB for InfluxDB High-availability edition:
               - `influxdata.n1.mxlarge_ha` refers to 2 CPU 8GB memory;
               - `influxdata.n1.xlarge_ha` refers to 4 CPU 16GB memory;
               - `influxdata.n1.2xlarge_ha` refers to 8 CPU 32 GB memory;
               - `influxdata.n1.4xlarge_ha` refers to 16 CPU 64 GB memory;
               - `influxdata.n1.8xlarge_ha` refers to 32 CPU 128 GB memory;
               - `influxdata.n1.16xlarge_ha` refers to 64 CPU 256 GB memory.
               - Following enumerative value for TSDB:
               - `tsdb.1x.basic` refers to basic edition I;
               - `tsdb.3x.basic` refers to basic edition II;
               - `tsdb.4x.basic` refers to basic edtion III;
               - `tsdb.12x.standard` refers to standard edition I;
               - `tsdb.24x.standard` refers to standard edition II;
               - `tsdb.48x.large` refers to ultimate edition I;
               - `tsdb.96x.large` refers to ultimate edition II.
        :param pulumi.Input[str] instance_storage: The storage capacity of the instance. Unit: GB. For example, the value 50 indicates 50 GB. Does not support shrink storage.
        :param pulumi.Input[str] payment_type: The billing method. Valid values: `PayAsYouGo` and `Subscription`. The `PayAsYouGo` value indicates the pay-as-you-go method, and the `Subscription` value indicates the subscription method.
        :param pulumi.Input[str] vswitch_id: The vswitch id.
        :param pulumi.Input[str] app_key: The app key.
        :param pulumi.Input[str] disk_category: The disk type of instance. Valid when the engine type is `tsdb_influxdb`. `cloud_ssd` refers to SSD disk, `cloud_efficiency` refers to efficiency disk, `cloud_essd` refers to ESSD PL1 disk. Valid values: `cloud_efficiency`, `cloud_essd`, `cloud_ssd`.
        :param pulumi.Input[str] duration: The duration.
        :param pulumi.Input[str] engine_type: The engine type of instance Enumerative: `tsdb_tsdb` refers to TSDB, `tsdb_influxdb` refers to TSDB for InfluxDB️.
        :param pulumi.Input[str] instance_alias: The alias of the instance.
        :param pulumi.Input[str] zone_id: The zone ID of the instance.
        """
        pulumi.set(__self__, "instance_class", instance_class)
        pulumi.set(__self__, "instance_storage", instance_storage)
        pulumi.set(__self__, "payment_type", payment_type)
        pulumi.set(__self__, "vswitch_id", vswitch_id)
        if app_key is not None:
            pulumi.set(__self__, "app_key", app_key)
        if disk_category is not None:
            pulumi.set(__self__, "disk_category", disk_category)
        if duration is not None:
            pulumi.set(__self__, "duration", duration)
        if engine_type is not None:
            pulumi.set(__self__, "engine_type", engine_type)
        if instance_alias is not None:
            pulumi.set(__self__, "instance_alias", instance_alias)
        if zone_id is not None:
            pulumi.set(__self__, "zone_id", zone_id)

    @property
    @pulumi.getter(name="instanceClass")
    def instance_class(self) -> pulumi.Input[str]:
        """
        The specification of the instance. 
        - Following enumerative value for TSDB for InfluxDB️ standart edition:
        - `influxdata.n1.mxlarge` refers to 2 CPU 8GB memory;
        - `influxdata.n1.xlarge` refers to 4 CPU 16GB memory;
        - `influxdata.n1.2xlarge` refers to 8 CPU 32 GB memory;
        - `influxdata.n1.4xlarge` refers to 16 CPU 64 GB memory;
        - `influxdata.n1.8xlarge` refers to 32 CPU 128 GB memory;
        - `influxdata.n1.16xlarge` refers to 64 CPU 256 GB memory.
        - Following enumerative value for TSDB for InfluxDB High-availability edition:
        - `influxdata.n1.mxlarge_ha` refers to 2 CPU 8GB memory;
        - `influxdata.n1.xlarge_ha` refers to 4 CPU 16GB memory;
        - `influxdata.n1.2xlarge_ha` refers to 8 CPU 32 GB memory;
        - `influxdata.n1.4xlarge_ha` refers to 16 CPU 64 GB memory;
        - `influxdata.n1.8xlarge_ha` refers to 32 CPU 128 GB memory;
        - `influxdata.n1.16xlarge_ha` refers to 64 CPU 256 GB memory.
        - Following enumerative value for TSDB:
        - `tsdb.1x.basic` refers to basic edition I;
        - `tsdb.3x.basic` refers to basic edition II;
        - `tsdb.4x.basic` refers to basic edtion III;
        - `tsdb.12x.standard` refers to standard edition I;
        - `tsdb.24x.standard` refers to standard edition II;
        - `tsdb.48x.large` refers to ultimate edition I;
        - `tsdb.96x.large` refers to ultimate edition II.
        """
        return pulumi.get(self, "instance_class")

    @instance_class.setter
    def instance_class(self, value: pulumi.Input[str]):
        pulumi.set(self, "instance_class", value)

    @property
    @pulumi.getter(name="instanceStorage")
    def instance_storage(self) -> pulumi.Input[str]:
        """
        The storage capacity of the instance. Unit: GB. For example, the value 50 indicates 50 GB. Does not support shrink storage.
        """
        return pulumi.get(self, "instance_storage")

    @instance_storage.setter
    def instance_storage(self, value: pulumi.Input[str]):
        pulumi.set(self, "instance_storage", value)

    @property
    @pulumi.getter(name="paymentType")
    def payment_type(self) -> pulumi.Input[str]:
        """
        The billing method. Valid values: `PayAsYouGo` and `Subscription`. The `PayAsYouGo` value indicates the pay-as-you-go method, and the `Subscription` value indicates the subscription method.
        """
        return pulumi.get(self, "payment_type")

    @payment_type.setter
    def payment_type(self, value: pulumi.Input[str]):
        pulumi.set(self, "payment_type", value)

    @property
    @pulumi.getter(name="vswitchId")
    def vswitch_id(self) -> pulumi.Input[str]:
        """
        The vswitch id.
        """
        return pulumi.get(self, "vswitch_id")

    @vswitch_id.setter
    def vswitch_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "vswitch_id", value)

    @property
    @pulumi.getter(name="appKey")
    def app_key(self) -> Optional[pulumi.Input[str]]:
        """
        The app key.
        """
        return pulumi.get(self, "app_key")

    @app_key.setter
    def app_key(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "app_key", value)

    @property
    @pulumi.getter(name="diskCategory")
    def disk_category(self) -> Optional[pulumi.Input[str]]:
        """
        The disk type of instance. Valid when the engine type is `tsdb_influxdb`. `cloud_ssd` refers to SSD disk, `cloud_efficiency` refers to efficiency disk, `cloud_essd` refers to ESSD PL1 disk. Valid values: `cloud_efficiency`, `cloud_essd`, `cloud_ssd`.
        """
        return pulumi.get(self, "disk_category")

    @disk_category.setter
    def disk_category(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "disk_category", value)

    @property
    @pulumi.getter
    def duration(self) -> Optional[pulumi.Input[str]]:
        """
        The duration.
        """
        return pulumi.get(self, "duration")

    @duration.setter
    def duration(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "duration", value)

    @property
    @pulumi.getter(name="engineType")
    def engine_type(self) -> Optional[pulumi.Input[str]]:
        """
        The engine type of instance Enumerative: `tsdb_tsdb` refers to TSDB, `tsdb_influxdb` refers to TSDB for InfluxDB️.
        """
        return pulumi.get(self, "engine_type")

    @engine_type.setter
    def engine_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "engine_type", value)

    @property
    @pulumi.getter(name="instanceAlias")
    def instance_alias(self) -> Optional[pulumi.Input[str]]:
        """
        The alias of the instance.
        """
        return pulumi.get(self, "instance_alias")

    @instance_alias.setter
    def instance_alias(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "instance_alias", value)

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> Optional[pulumi.Input[str]]:
        """
        The zone ID of the instance.
        """
        return pulumi.get(self, "zone_id")

    @zone_id.setter
    def zone_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "zone_id", value)


@pulumi.input_type
class _InstanceState:
    def __init__(__self__, *,
                 app_key: Optional[pulumi.Input[str]] = None,
                 disk_category: Optional[pulumi.Input[str]] = None,
                 duration: Optional[pulumi.Input[str]] = None,
                 engine_type: Optional[pulumi.Input[str]] = None,
                 instance_alias: Optional[pulumi.Input[str]] = None,
                 instance_class: Optional[pulumi.Input[str]] = None,
                 instance_storage: Optional[pulumi.Input[str]] = None,
                 payment_type: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None,
                 vswitch_id: Optional[pulumi.Input[str]] = None,
                 zone_id: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering Instance resources.
        :param pulumi.Input[str] app_key: The app key.
        :param pulumi.Input[str] disk_category: The disk type of instance. Valid when the engine type is `tsdb_influxdb`. `cloud_ssd` refers to SSD disk, `cloud_efficiency` refers to efficiency disk, `cloud_essd` refers to ESSD PL1 disk. Valid values: `cloud_efficiency`, `cloud_essd`, `cloud_ssd`.
        :param pulumi.Input[str] duration: The duration.
        :param pulumi.Input[str] engine_type: The engine type of instance Enumerative: `tsdb_tsdb` refers to TSDB, `tsdb_influxdb` refers to TSDB for InfluxDB️.
        :param pulumi.Input[str] instance_alias: The alias of the instance.
        :param pulumi.Input[str] instance_class: The specification of the instance. 
               - Following enumerative value for TSDB for InfluxDB️ standart edition:
               - `influxdata.n1.mxlarge` refers to 2 CPU 8GB memory;
               - `influxdata.n1.xlarge` refers to 4 CPU 16GB memory;
               - `influxdata.n1.2xlarge` refers to 8 CPU 32 GB memory;
               - `influxdata.n1.4xlarge` refers to 16 CPU 64 GB memory;
               - `influxdata.n1.8xlarge` refers to 32 CPU 128 GB memory;
               - `influxdata.n1.16xlarge` refers to 64 CPU 256 GB memory.
               - Following enumerative value for TSDB for InfluxDB High-availability edition:
               - `influxdata.n1.mxlarge_ha` refers to 2 CPU 8GB memory;
               - `influxdata.n1.xlarge_ha` refers to 4 CPU 16GB memory;
               - `influxdata.n1.2xlarge_ha` refers to 8 CPU 32 GB memory;
               - `influxdata.n1.4xlarge_ha` refers to 16 CPU 64 GB memory;
               - `influxdata.n1.8xlarge_ha` refers to 32 CPU 128 GB memory;
               - `influxdata.n1.16xlarge_ha` refers to 64 CPU 256 GB memory.
               - Following enumerative value for TSDB:
               - `tsdb.1x.basic` refers to basic edition I;
               - `tsdb.3x.basic` refers to basic edition II;
               - `tsdb.4x.basic` refers to basic edtion III;
               - `tsdb.12x.standard` refers to standard edition I;
               - `tsdb.24x.standard` refers to standard edition II;
               - `tsdb.48x.large` refers to ultimate edition I;
               - `tsdb.96x.large` refers to ultimate edition II.
        :param pulumi.Input[str] instance_storage: The storage capacity of the instance. Unit: GB. For example, the value 50 indicates 50 GB. Does not support shrink storage.
        :param pulumi.Input[str] payment_type: The billing method. Valid values: `PayAsYouGo` and `Subscription`. The `PayAsYouGo` value indicates the pay-as-you-go method, and the `Subscription` value indicates the subscription method.
        :param pulumi.Input[str] status: Instance status, enumerative: `ACTIVATION`, `DELETED`, `CREATING`, `CLASS_CHANGING`, `LOCKED`.
        :param pulumi.Input[str] vswitch_id: The vswitch id.
        :param pulumi.Input[str] zone_id: The zone ID of the instance.
        """
        if app_key is not None:
            pulumi.set(__self__, "app_key", app_key)
        if disk_category is not None:
            pulumi.set(__self__, "disk_category", disk_category)
        if duration is not None:
            pulumi.set(__self__, "duration", duration)
        if engine_type is not None:
            pulumi.set(__self__, "engine_type", engine_type)
        if instance_alias is not None:
            pulumi.set(__self__, "instance_alias", instance_alias)
        if instance_class is not None:
            pulumi.set(__self__, "instance_class", instance_class)
        if instance_storage is not None:
            pulumi.set(__self__, "instance_storage", instance_storage)
        if payment_type is not None:
            pulumi.set(__self__, "payment_type", payment_type)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if vswitch_id is not None:
            pulumi.set(__self__, "vswitch_id", vswitch_id)
        if zone_id is not None:
            pulumi.set(__self__, "zone_id", zone_id)

    @property
    @pulumi.getter(name="appKey")
    def app_key(self) -> Optional[pulumi.Input[str]]:
        """
        The app key.
        """
        return pulumi.get(self, "app_key")

    @app_key.setter
    def app_key(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "app_key", value)

    @property
    @pulumi.getter(name="diskCategory")
    def disk_category(self) -> Optional[pulumi.Input[str]]:
        """
        The disk type of instance. Valid when the engine type is `tsdb_influxdb`. `cloud_ssd` refers to SSD disk, `cloud_efficiency` refers to efficiency disk, `cloud_essd` refers to ESSD PL1 disk. Valid values: `cloud_efficiency`, `cloud_essd`, `cloud_ssd`.
        """
        return pulumi.get(self, "disk_category")

    @disk_category.setter
    def disk_category(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "disk_category", value)

    @property
    @pulumi.getter
    def duration(self) -> Optional[pulumi.Input[str]]:
        """
        The duration.
        """
        return pulumi.get(self, "duration")

    @duration.setter
    def duration(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "duration", value)

    @property
    @pulumi.getter(name="engineType")
    def engine_type(self) -> Optional[pulumi.Input[str]]:
        """
        The engine type of instance Enumerative: `tsdb_tsdb` refers to TSDB, `tsdb_influxdb` refers to TSDB for InfluxDB️.
        """
        return pulumi.get(self, "engine_type")

    @engine_type.setter
    def engine_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "engine_type", value)

    @property
    @pulumi.getter(name="instanceAlias")
    def instance_alias(self) -> Optional[pulumi.Input[str]]:
        """
        The alias of the instance.
        """
        return pulumi.get(self, "instance_alias")

    @instance_alias.setter
    def instance_alias(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "instance_alias", value)

    @property
    @pulumi.getter(name="instanceClass")
    def instance_class(self) -> Optional[pulumi.Input[str]]:
        """
        The specification of the instance. 
        - Following enumerative value for TSDB for InfluxDB️ standart edition:
        - `influxdata.n1.mxlarge` refers to 2 CPU 8GB memory;
        - `influxdata.n1.xlarge` refers to 4 CPU 16GB memory;
        - `influxdata.n1.2xlarge` refers to 8 CPU 32 GB memory;
        - `influxdata.n1.4xlarge` refers to 16 CPU 64 GB memory;
        - `influxdata.n1.8xlarge` refers to 32 CPU 128 GB memory;
        - `influxdata.n1.16xlarge` refers to 64 CPU 256 GB memory.
        - Following enumerative value for TSDB for InfluxDB High-availability edition:
        - `influxdata.n1.mxlarge_ha` refers to 2 CPU 8GB memory;
        - `influxdata.n1.xlarge_ha` refers to 4 CPU 16GB memory;
        - `influxdata.n1.2xlarge_ha` refers to 8 CPU 32 GB memory;
        - `influxdata.n1.4xlarge_ha` refers to 16 CPU 64 GB memory;
        - `influxdata.n1.8xlarge_ha` refers to 32 CPU 128 GB memory;
        - `influxdata.n1.16xlarge_ha` refers to 64 CPU 256 GB memory.
        - Following enumerative value for TSDB:
        - `tsdb.1x.basic` refers to basic edition I;
        - `tsdb.3x.basic` refers to basic edition II;
        - `tsdb.4x.basic` refers to basic edtion III;
        - `tsdb.12x.standard` refers to standard edition I;
        - `tsdb.24x.standard` refers to standard edition II;
        - `tsdb.48x.large` refers to ultimate edition I;
        - `tsdb.96x.large` refers to ultimate edition II.
        """
        return pulumi.get(self, "instance_class")

    @instance_class.setter
    def instance_class(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "instance_class", value)

    @property
    @pulumi.getter(name="instanceStorage")
    def instance_storage(self) -> Optional[pulumi.Input[str]]:
        """
        The storage capacity of the instance. Unit: GB. For example, the value 50 indicates 50 GB. Does not support shrink storage.
        """
        return pulumi.get(self, "instance_storage")

    @instance_storage.setter
    def instance_storage(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "instance_storage", value)

    @property
    @pulumi.getter(name="paymentType")
    def payment_type(self) -> Optional[pulumi.Input[str]]:
        """
        The billing method. Valid values: `PayAsYouGo` and `Subscription`. The `PayAsYouGo` value indicates the pay-as-you-go method, and the `Subscription` value indicates the subscription method.
        """
        return pulumi.get(self, "payment_type")

    @payment_type.setter
    def payment_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "payment_type", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        Instance status, enumerative: `ACTIVATION`, `DELETED`, `CREATING`, `CLASS_CHANGING`, `LOCKED`.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="vswitchId")
    def vswitch_id(self) -> Optional[pulumi.Input[str]]:
        """
        The vswitch id.
        """
        return pulumi.get(self, "vswitch_id")

    @vswitch_id.setter
    def vswitch_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "vswitch_id", value)

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> Optional[pulumi.Input[str]]:
        """
        The zone ID of the instance.
        """
        return pulumi.get(self, "zone_id")

    @zone_id.setter
    def zone_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "zone_id", value)


class Instance(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 app_key: Optional[pulumi.Input[str]] = None,
                 disk_category: Optional[pulumi.Input[str]] = None,
                 duration: Optional[pulumi.Input[str]] = None,
                 engine_type: Optional[pulumi.Input[str]] = None,
                 instance_alias: Optional[pulumi.Input[str]] = None,
                 instance_class: Optional[pulumi.Input[str]] = None,
                 instance_storage: Optional[pulumi.Input[str]] = None,
                 payment_type: Optional[pulumi.Input[str]] = None,
                 vswitch_id: Optional[pulumi.Input[str]] = None,
                 zone_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a Time Series Database (TSDB) Instance resource.

        For information about Time Series Database (TSDB) Instance and how to use it, see [What is Time Series Database (TSDB)](https://www.alibabacloud.com/help/en/doc-detail/55652.htm).

        > **NOTE:** Available in v1.112.0+.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        example_zones = alicloud.tsdb.get_zones()
        example_network = alicloud.vpc.Network("exampleNetwork", cidr_block="192.168.0.0/16")
        example_switch = alicloud.vpc.Switch("exampleSwitch",
            availability_zone=example_zones.ids[0],
            cidr_block="192.168.1.0/24",
            vpc_id=example_network.id)
        example_instance = alicloud.tsdb.Instance("exampleInstance",
            payment_type="PayAsYouGo",
            vswitch_id=example_switch.id,
            instance_storage="50",
            instance_class="tsdb.1x.basic",
            engine_type="tsdb_tsdb",
            instance_alias="tf-testaccTsdbInstance")
        ```

        ## Import

        TSDB Instance can be imported using the id, e.g.

        ```sh
         $ pulumi import alicloud:tsdb/instance:Instance example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] app_key: The app key.
        :param pulumi.Input[str] disk_category: The disk type of instance. Valid when the engine type is `tsdb_influxdb`. `cloud_ssd` refers to SSD disk, `cloud_efficiency` refers to efficiency disk, `cloud_essd` refers to ESSD PL1 disk. Valid values: `cloud_efficiency`, `cloud_essd`, `cloud_ssd`.
        :param pulumi.Input[str] duration: The duration.
        :param pulumi.Input[str] engine_type: The engine type of instance Enumerative: `tsdb_tsdb` refers to TSDB, `tsdb_influxdb` refers to TSDB for InfluxDB️.
        :param pulumi.Input[str] instance_alias: The alias of the instance.
        :param pulumi.Input[str] instance_class: The specification of the instance. 
               - Following enumerative value for TSDB for InfluxDB️ standart edition:
               - `influxdata.n1.mxlarge` refers to 2 CPU 8GB memory;
               - `influxdata.n1.xlarge` refers to 4 CPU 16GB memory;
               - `influxdata.n1.2xlarge` refers to 8 CPU 32 GB memory;
               - `influxdata.n1.4xlarge` refers to 16 CPU 64 GB memory;
               - `influxdata.n1.8xlarge` refers to 32 CPU 128 GB memory;
               - `influxdata.n1.16xlarge` refers to 64 CPU 256 GB memory.
               - Following enumerative value for TSDB for InfluxDB High-availability edition:
               - `influxdata.n1.mxlarge_ha` refers to 2 CPU 8GB memory;
               - `influxdata.n1.xlarge_ha` refers to 4 CPU 16GB memory;
               - `influxdata.n1.2xlarge_ha` refers to 8 CPU 32 GB memory;
               - `influxdata.n1.4xlarge_ha` refers to 16 CPU 64 GB memory;
               - `influxdata.n1.8xlarge_ha` refers to 32 CPU 128 GB memory;
               - `influxdata.n1.16xlarge_ha` refers to 64 CPU 256 GB memory.
               - Following enumerative value for TSDB:
               - `tsdb.1x.basic` refers to basic edition I;
               - `tsdb.3x.basic` refers to basic edition II;
               - `tsdb.4x.basic` refers to basic edtion III;
               - `tsdb.12x.standard` refers to standard edition I;
               - `tsdb.24x.standard` refers to standard edition II;
               - `tsdb.48x.large` refers to ultimate edition I;
               - `tsdb.96x.large` refers to ultimate edition II.
        :param pulumi.Input[str] instance_storage: The storage capacity of the instance. Unit: GB. For example, the value 50 indicates 50 GB. Does not support shrink storage.
        :param pulumi.Input[str] payment_type: The billing method. Valid values: `PayAsYouGo` and `Subscription`. The `PayAsYouGo` value indicates the pay-as-you-go method, and the `Subscription` value indicates the subscription method.
        :param pulumi.Input[str] vswitch_id: The vswitch id.
        :param pulumi.Input[str] zone_id: The zone ID of the instance.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: InstanceArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Time Series Database (TSDB) Instance resource.

        For information about Time Series Database (TSDB) Instance and how to use it, see [What is Time Series Database (TSDB)](https://www.alibabacloud.com/help/en/doc-detail/55652.htm).

        > **NOTE:** Available in v1.112.0+.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        example_zones = alicloud.tsdb.get_zones()
        example_network = alicloud.vpc.Network("exampleNetwork", cidr_block="192.168.0.0/16")
        example_switch = alicloud.vpc.Switch("exampleSwitch",
            availability_zone=example_zones.ids[0],
            cidr_block="192.168.1.0/24",
            vpc_id=example_network.id)
        example_instance = alicloud.tsdb.Instance("exampleInstance",
            payment_type="PayAsYouGo",
            vswitch_id=example_switch.id,
            instance_storage="50",
            instance_class="tsdb.1x.basic",
            engine_type="tsdb_tsdb",
            instance_alias="tf-testaccTsdbInstance")
        ```

        ## Import

        TSDB Instance can be imported using the id, e.g.

        ```sh
         $ pulumi import alicloud:tsdb/instance:Instance example <id>
        ```

        :param str resource_name: The name of the resource.
        :param InstanceArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(InstanceArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 app_key: Optional[pulumi.Input[str]] = None,
                 disk_category: Optional[pulumi.Input[str]] = None,
                 duration: Optional[pulumi.Input[str]] = None,
                 engine_type: Optional[pulumi.Input[str]] = None,
                 instance_alias: Optional[pulumi.Input[str]] = None,
                 instance_class: Optional[pulumi.Input[str]] = None,
                 instance_storage: Optional[pulumi.Input[str]] = None,
                 payment_type: Optional[pulumi.Input[str]] = None,
                 vswitch_id: Optional[pulumi.Input[str]] = None,
                 zone_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = InstanceArgs.__new__(InstanceArgs)

            __props__.__dict__["app_key"] = app_key
            __props__.__dict__["disk_category"] = disk_category
            __props__.__dict__["duration"] = duration
            __props__.__dict__["engine_type"] = engine_type
            __props__.__dict__["instance_alias"] = instance_alias
            if instance_class is None and not opts.urn:
                raise TypeError("Missing required property 'instance_class'")
            __props__.__dict__["instance_class"] = instance_class
            if instance_storage is None and not opts.urn:
                raise TypeError("Missing required property 'instance_storage'")
            __props__.__dict__["instance_storage"] = instance_storage
            if payment_type is None and not opts.urn:
                raise TypeError("Missing required property 'payment_type'")
            __props__.__dict__["payment_type"] = payment_type
            if vswitch_id is None and not opts.urn:
                raise TypeError("Missing required property 'vswitch_id'")
            __props__.__dict__["vswitch_id"] = vswitch_id
            __props__.__dict__["zone_id"] = zone_id
            __props__.__dict__["status"] = None
        super(Instance, __self__).__init__(
            'alicloud:tsdb/instance:Instance',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            app_key: Optional[pulumi.Input[str]] = None,
            disk_category: Optional[pulumi.Input[str]] = None,
            duration: Optional[pulumi.Input[str]] = None,
            engine_type: Optional[pulumi.Input[str]] = None,
            instance_alias: Optional[pulumi.Input[str]] = None,
            instance_class: Optional[pulumi.Input[str]] = None,
            instance_storage: Optional[pulumi.Input[str]] = None,
            payment_type: Optional[pulumi.Input[str]] = None,
            status: Optional[pulumi.Input[str]] = None,
            vswitch_id: Optional[pulumi.Input[str]] = None,
            zone_id: Optional[pulumi.Input[str]] = None) -> 'Instance':
        """
        Get an existing Instance resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] app_key: The app key.
        :param pulumi.Input[str] disk_category: The disk type of instance. Valid when the engine type is `tsdb_influxdb`. `cloud_ssd` refers to SSD disk, `cloud_efficiency` refers to efficiency disk, `cloud_essd` refers to ESSD PL1 disk. Valid values: `cloud_efficiency`, `cloud_essd`, `cloud_ssd`.
        :param pulumi.Input[str] duration: The duration.
        :param pulumi.Input[str] engine_type: The engine type of instance Enumerative: `tsdb_tsdb` refers to TSDB, `tsdb_influxdb` refers to TSDB for InfluxDB️.
        :param pulumi.Input[str] instance_alias: The alias of the instance.
        :param pulumi.Input[str] instance_class: The specification of the instance. 
               - Following enumerative value for TSDB for InfluxDB️ standart edition:
               - `influxdata.n1.mxlarge` refers to 2 CPU 8GB memory;
               - `influxdata.n1.xlarge` refers to 4 CPU 16GB memory;
               - `influxdata.n1.2xlarge` refers to 8 CPU 32 GB memory;
               - `influxdata.n1.4xlarge` refers to 16 CPU 64 GB memory;
               - `influxdata.n1.8xlarge` refers to 32 CPU 128 GB memory;
               - `influxdata.n1.16xlarge` refers to 64 CPU 256 GB memory.
               - Following enumerative value for TSDB for InfluxDB High-availability edition:
               - `influxdata.n1.mxlarge_ha` refers to 2 CPU 8GB memory;
               - `influxdata.n1.xlarge_ha` refers to 4 CPU 16GB memory;
               - `influxdata.n1.2xlarge_ha` refers to 8 CPU 32 GB memory;
               - `influxdata.n1.4xlarge_ha` refers to 16 CPU 64 GB memory;
               - `influxdata.n1.8xlarge_ha` refers to 32 CPU 128 GB memory;
               - `influxdata.n1.16xlarge_ha` refers to 64 CPU 256 GB memory.
               - Following enumerative value for TSDB:
               - `tsdb.1x.basic` refers to basic edition I;
               - `tsdb.3x.basic` refers to basic edition II;
               - `tsdb.4x.basic` refers to basic edtion III;
               - `tsdb.12x.standard` refers to standard edition I;
               - `tsdb.24x.standard` refers to standard edition II;
               - `tsdb.48x.large` refers to ultimate edition I;
               - `tsdb.96x.large` refers to ultimate edition II.
        :param pulumi.Input[str] instance_storage: The storage capacity of the instance. Unit: GB. For example, the value 50 indicates 50 GB. Does not support shrink storage.
        :param pulumi.Input[str] payment_type: The billing method. Valid values: `PayAsYouGo` and `Subscription`. The `PayAsYouGo` value indicates the pay-as-you-go method, and the `Subscription` value indicates the subscription method.
        :param pulumi.Input[str] status: Instance status, enumerative: `ACTIVATION`, `DELETED`, `CREATING`, `CLASS_CHANGING`, `LOCKED`.
        :param pulumi.Input[str] vswitch_id: The vswitch id.
        :param pulumi.Input[str] zone_id: The zone ID of the instance.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _InstanceState.__new__(_InstanceState)

        __props__.__dict__["app_key"] = app_key
        __props__.__dict__["disk_category"] = disk_category
        __props__.__dict__["duration"] = duration
        __props__.__dict__["engine_type"] = engine_type
        __props__.__dict__["instance_alias"] = instance_alias
        __props__.__dict__["instance_class"] = instance_class
        __props__.__dict__["instance_storage"] = instance_storage
        __props__.__dict__["payment_type"] = payment_type
        __props__.__dict__["status"] = status
        __props__.__dict__["vswitch_id"] = vswitch_id
        __props__.__dict__["zone_id"] = zone_id
        return Instance(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="appKey")
    def app_key(self) -> pulumi.Output[Optional[str]]:
        """
        The app key.
        """
        return pulumi.get(self, "app_key")

    @property
    @pulumi.getter(name="diskCategory")
    def disk_category(self) -> pulumi.Output[Optional[str]]:
        """
        The disk type of instance. Valid when the engine type is `tsdb_influxdb`. `cloud_ssd` refers to SSD disk, `cloud_efficiency` refers to efficiency disk, `cloud_essd` refers to ESSD PL1 disk. Valid values: `cloud_efficiency`, `cloud_essd`, `cloud_ssd`.
        """
        return pulumi.get(self, "disk_category")

    @property
    @pulumi.getter
    def duration(self) -> pulumi.Output[Optional[str]]:
        """
        The duration.
        """
        return pulumi.get(self, "duration")

    @property
    @pulumi.getter(name="engineType")
    def engine_type(self) -> pulumi.Output[Optional[str]]:
        """
        The engine type of instance Enumerative: `tsdb_tsdb` refers to TSDB, `tsdb_influxdb` refers to TSDB for InfluxDB️.
        """
        return pulumi.get(self, "engine_type")

    @property
    @pulumi.getter(name="instanceAlias")
    def instance_alias(self) -> pulumi.Output[Optional[str]]:
        """
        The alias of the instance.
        """
        return pulumi.get(self, "instance_alias")

    @property
    @pulumi.getter(name="instanceClass")
    def instance_class(self) -> pulumi.Output[str]:
        """
        The specification of the instance. 
        - Following enumerative value for TSDB for InfluxDB️ standart edition:
        - `influxdata.n1.mxlarge` refers to 2 CPU 8GB memory;
        - `influxdata.n1.xlarge` refers to 4 CPU 16GB memory;
        - `influxdata.n1.2xlarge` refers to 8 CPU 32 GB memory;
        - `influxdata.n1.4xlarge` refers to 16 CPU 64 GB memory;
        - `influxdata.n1.8xlarge` refers to 32 CPU 128 GB memory;
        - `influxdata.n1.16xlarge` refers to 64 CPU 256 GB memory.
        - Following enumerative value for TSDB for InfluxDB High-availability edition:
        - `influxdata.n1.mxlarge_ha` refers to 2 CPU 8GB memory;
        - `influxdata.n1.xlarge_ha` refers to 4 CPU 16GB memory;
        - `influxdata.n1.2xlarge_ha` refers to 8 CPU 32 GB memory;
        - `influxdata.n1.4xlarge_ha` refers to 16 CPU 64 GB memory;
        - `influxdata.n1.8xlarge_ha` refers to 32 CPU 128 GB memory;
        - `influxdata.n1.16xlarge_ha` refers to 64 CPU 256 GB memory.
        - Following enumerative value for TSDB:
        - `tsdb.1x.basic` refers to basic edition I;
        - `tsdb.3x.basic` refers to basic edition II;
        - `tsdb.4x.basic` refers to basic edtion III;
        - `tsdb.12x.standard` refers to standard edition I;
        - `tsdb.24x.standard` refers to standard edition II;
        - `tsdb.48x.large` refers to ultimate edition I;
        - `tsdb.96x.large` refers to ultimate edition II.
        """
        return pulumi.get(self, "instance_class")

    @property
    @pulumi.getter(name="instanceStorage")
    def instance_storage(self) -> pulumi.Output[str]:
        """
        The storage capacity of the instance. Unit: GB. For example, the value 50 indicates 50 GB. Does not support shrink storage.
        """
        return pulumi.get(self, "instance_storage")

    @property
    @pulumi.getter(name="paymentType")
    def payment_type(self) -> pulumi.Output[str]:
        """
        The billing method. Valid values: `PayAsYouGo` and `Subscription`. The `PayAsYouGo` value indicates the pay-as-you-go method, and the `Subscription` value indicates the subscription method.
        """
        return pulumi.get(self, "payment_type")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[str]:
        """
        Instance status, enumerative: `ACTIVATION`, `DELETED`, `CREATING`, `CLASS_CHANGING`, `LOCKED`.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="vswitchId")
    def vswitch_id(self) -> pulumi.Output[str]:
        """
        The vswitch id.
        """
        return pulumi.get(self, "vswitch_id")

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> pulumi.Output[str]:
        """
        The zone ID of the instance.
        """
        return pulumi.get(self, "zone_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = ['KeyPairArgs', 'KeyPair']

@pulumi.input_type
class KeyPairArgs:
    def __init__(__self__, *,
                 key_pair_name: pulumi.Input[str],
                 public_key_body: pulumi.Input[str]):
        """
        The set of arguments for constructing a KeyPair resource.
        :param pulumi.Input[str] key_pair_name: The Key Name.
        :param pulumi.Input[str] public_key_body: The public key body.
        """
        pulumi.set(__self__, "key_pair_name", key_pair_name)
        pulumi.set(__self__, "public_key_body", public_key_body)

    @property
    @pulumi.getter(name="keyPairName")
    def key_pair_name(self) -> pulumi.Input[str]:
        """
        The Key Name.
        """
        return pulumi.get(self, "key_pair_name")

    @key_pair_name.setter
    def key_pair_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "key_pair_name", value)

    @property
    @pulumi.getter(name="publicKeyBody")
    def public_key_body(self) -> pulumi.Input[str]:
        """
        The public key body.
        """
        return pulumi.get(self, "public_key_body")

    @public_key_body.setter
    def public_key_body(self, value: pulumi.Input[str]):
        pulumi.set(self, "public_key_body", value)


@pulumi.input_type
class _KeyPairState:
    def __init__(__self__, *,
                 key_pair_name: Optional[pulumi.Input[str]] = None,
                 public_key_body: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering KeyPair resources.
        :param pulumi.Input[str] key_pair_name: The Key Name.
        :param pulumi.Input[str] public_key_body: The public key body.
        """
        if key_pair_name is not None:
            pulumi.set(__self__, "key_pair_name", key_pair_name)
        if public_key_body is not None:
            pulumi.set(__self__, "public_key_body", public_key_body)

    @property
    @pulumi.getter(name="keyPairName")
    def key_pair_name(self) -> Optional[pulumi.Input[str]]:
        """
        The Key Name.
        """
        return pulumi.get(self, "key_pair_name")

    @key_pair_name.setter
    def key_pair_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "key_pair_name", value)

    @property
    @pulumi.getter(name="publicKeyBody")
    def public_key_body(self) -> Optional[pulumi.Input[str]]:
        """
        The public key body.
        """
        return pulumi.get(self, "public_key_body")

    @public_key_body.setter
    def public_key_body(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "public_key_body", value)


class KeyPair(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 key_pair_name: Optional[pulumi.Input[str]] = None,
                 public_key_body: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a Elastic Cloud Phone (ECP) Key Pair resource.

        For information about Elastic Cloud Phone (ECP) Key Pair and how to use it, see [What is Key Pair](https://help.aliyun.com/document_detail/257197.html).

        > **NOTE:** Available in v1.130.0+.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        example = alicloud.ecp.KeyPair("example",
            key_pair_name="my-KeyPair",
            public_key_body="ssh-rsa AAAAxxxxxxxxxxtyuudsfsg")
        ```

        ## Import

        Elastic Cloud Phone (ECP) Key Pair can be imported using the id, e.g.

        ```sh
         $ pulumi import alicloud:ecp/keyPair:KeyPair example <key_pair_name>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] key_pair_name: The Key Name.
        :param pulumi.Input[str] public_key_body: The public key body.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: KeyPairArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Elastic Cloud Phone (ECP) Key Pair resource.

        For information about Elastic Cloud Phone (ECP) Key Pair and how to use it, see [What is Key Pair](https://help.aliyun.com/document_detail/257197.html).

        > **NOTE:** Available in v1.130.0+.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        example = alicloud.ecp.KeyPair("example",
            key_pair_name="my-KeyPair",
            public_key_body="ssh-rsa AAAAxxxxxxxxxxtyuudsfsg")
        ```

        ## Import

        Elastic Cloud Phone (ECP) Key Pair can be imported using the id, e.g.

        ```sh
         $ pulumi import alicloud:ecp/keyPair:KeyPair example <key_pair_name>
        ```

        :param str resource_name: The name of the resource.
        :param KeyPairArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(KeyPairArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 key_pair_name: Optional[pulumi.Input[str]] = None,
                 public_key_body: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = KeyPairArgs.__new__(KeyPairArgs)

            if key_pair_name is None and not opts.urn:
                raise TypeError("Missing required property 'key_pair_name'")
            __props__.__dict__["key_pair_name"] = key_pair_name
            if public_key_body is None and not opts.urn:
                raise TypeError("Missing required property 'public_key_body'")
            __props__.__dict__["public_key_body"] = public_key_body
        super(KeyPair, __self__).__init__(
            'alicloud:ecp/keyPair:KeyPair',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            key_pair_name: Optional[pulumi.Input[str]] = None,
            public_key_body: Optional[pulumi.Input[str]] = None) -> 'KeyPair':
        """
        Get an existing KeyPair resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] key_pair_name: The Key Name.
        :param pulumi.Input[str] public_key_body: The public key body.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _KeyPairState.__new__(_KeyPairState)

        __props__.__dict__["key_pair_name"] = key_pair_name
        __props__.__dict__["public_key_body"] = public_key_body
        return KeyPair(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="keyPairName")
    def key_pair_name(self) -> pulumi.Output[str]:
        """
        The Key Name.
        """
        return pulumi.get(self, "key_pair_name")

    @property
    @pulumi.getter(name="publicKeyBody")
    def public_key_body(self) -> pulumi.Output[str]:
        """
        The public key body.
        """
        return pulumi.get(self, "public_key_body")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = ['FilesetArgs', 'Fileset']

@pulumi.input_type
class FilesetArgs:
    def __init__(__self__, *,
                 file_system_id: pulumi.Input[str],
                 file_system_path: pulumi.Input[str],
                 description: Optional[pulumi.Input[str]] = None,
                 dry_run: Optional[pulumi.Input[bool]] = None):
        """
        The set of arguments for constructing a Fileset resource.
        :param pulumi.Input[str] file_system_id: The ID of the file system.
        :param pulumi.Input[str] file_system_path: The path of the fileset.
        :param pulumi.Input[str] description: The description of the Fileset. It must be `2` to `128` characters in length and must start with a letter or Chinese, but cannot start with `https://` or `https://`.
        :param pulumi.Input[bool] dry_run: The dry run.
        """
        pulumi.set(__self__, "file_system_id", file_system_id)
        pulumi.set(__self__, "file_system_path", file_system_path)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if dry_run is not None:
            pulumi.set(__self__, "dry_run", dry_run)

    @property
    @pulumi.getter(name="fileSystemId")
    def file_system_id(self) -> pulumi.Input[str]:
        """
        The ID of the file system.
        """
        return pulumi.get(self, "file_system_id")

    @file_system_id.setter
    def file_system_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "file_system_id", value)

    @property
    @pulumi.getter(name="fileSystemPath")
    def file_system_path(self) -> pulumi.Input[str]:
        """
        The path of the fileset.
        """
        return pulumi.get(self, "file_system_path")

    @file_system_path.setter
    def file_system_path(self, value: pulumi.Input[str]):
        pulumi.set(self, "file_system_path", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        The description of the Fileset. It must be `2` to `128` characters in length and must start with a letter or Chinese, but cannot start with `https://` or `https://`.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="dryRun")
    def dry_run(self) -> Optional[pulumi.Input[bool]]:
        """
        The dry run.
        """
        return pulumi.get(self, "dry_run")

    @dry_run.setter
    def dry_run(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "dry_run", value)


@pulumi.input_type
class _FilesetState:
    def __init__(__self__, *,
                 description: Optional[pulumi.Input[str]] = None,
                 dry_run: Optional[pulumi.Input[bool]] = None,
                 file_system_id: Optional[pulumi.Input[str]] = None,
                 file_system_path: Optional[pulumi.Input[str]] = None,
                 fileset_id: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering Fileset resources.
        :param pulumi.Input[str] description: The description of the Fileset. It must be `2` to `128` characters in length and must start with a letter or Chinese, but cannot start with `https://` or `https://`.
        :param pulumi.Input[bool] dry_run: The dry run.
        :param pulumi.Input[str] file_system_id: The ID of the file system.
        :param pulumi.Input[str] file_system_path: The path of the fileset.
        :param pulumi.Input[str] fileset_id: The first ID of the resource.
        :param pulumi.Input[str] status: The status of the fileset.
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if dry_run is not None:
            pulumi.set(__self__, "dry_run", dry_run)
        if file_system_id is not None:
            pulumi.set(__self__, "file_system_id", file_system_id)
        if file_system_path is not None:
            pulumi.set(__self__, "file_system_path", file_system_path)
        if fileset_id is not None:
            pulumi.set(__self__, "fileset_id", fileset_id)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        The description of the Fileset. It must be `2` to `128` characters in length and must start with a letter or Chinese, but cannot start with `https://` or `https://`.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="dryRun")
    def dry_run(self) -> Optional[pulumi.Input[bool]]:
        """
        The dry run.
        """
        return pulumi.get(self, "dry_run")

    @dry_run.setter
    def dry_run(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "dry_run", value)

    @property
    @pulumi.getter(name="fileSystemId")
    def file_system_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the file system.
        """
        return pulumi.get(self, "file_system_id")

    @file_system_id.setter
    def file_system_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "file_system_id", value)

    @property
    @pulumi.getter(name="fileSystemPath")
    def file_system_path(self) -> Optional[pulumi.Input[str]]:
        """
        The path of the fileset.
        """
        return pulumi.get(self, "file_system_path")

    @file_system_path.setter
    def file_system_path(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "file_system_path", value)

    @property
    @pulumi.getter(name="filesetId")
    def fileset_id(self) -> Optional[pulumi.Input[str]]:
        """
        The first ID of the resource.
        """
        return pulumi.get(self, "fileset_id")

    @fileset_id.setter
    def fileset_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "fileset_id", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        The status of the fileset.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)


class Fileset(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 dry_run: Optional[pulumi.Input[bool]] = None,
                 file_system_id: Optional[pulumi.Input[str]] = None,
                 file_system_path: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a Network Attached Storage (NAS) Fileset resource.

        For information about Network Attached Storage (NAS) Fileset and how to use it, see [What is Fileset](https://www.alibabacloud.com/help/en/doc-detail/27530.html).

        > **NOTE:** Available in v1.153.0+.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        example_zones = alicloud.nas.get_zones(file_system_type="cpfs")
        example_network = alicloud.vpc.Network("exampleNetwork",
            vpc_name="terraform-example",
            cidr_block="172.17.3.0/24")
        example_switch = alicloud.vpc.Switch("exampleSwitch",
            vswitch_name="terraform-example",
            cidr_block="172.17.3.0/24",
            vpc_id=example_network.id,
            zone_id=example_zones.zones[1].zone_id)
        example_file_system = alicloud.nas.FileSystem("exampleFileSystem",
            protocol_type="cpfs",
            storage_type="advance_200",
            file_system_type="cpfs",
            capacity=3600,
            description="terraform-example",
            zone_id=example_zones.zones[1].zone_id,
            vpc_id=example_network.id,
            vswitch_id=example_switch.id)
        example_fileset = alicloud.nas.Fileset("exampleFileset",
            file_system_id=example_file_system.id,
            description="terraform-example",
            file_system_path="/example_path/")
        ```

        ## Import

        Network Attached Storage (NAS) Fileset can be imported using the id, e.g.

        ```sh
         $ pulumi import alicloud:nas/fileset:Fileset example <file_system_id>:<fileset_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] description: The description of the Fileset. It must be `2` to `128` characters in length and must start with a letter or Chinese, but cannot start with `https://` or `https://`.
        :param pulumi.Input[bool] dry_run: The dry run.
        :param pulumi.Input[str] file_system_id: The ID of the file system.
        :param pulumi.Input[str] file_system_path: The path of the fileset.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: FilesetArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Network Attached Storage (NAS) Fileset resource.

        For information about Network Attached Storage (NAS) Fileset and how to use it, see [What is Fileset](https://www.alibabacloud.com/help/en/doc-detail/27530.html).

        > **NOTE:** Available in v1.153.0+.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        example_zones = alicloud.nas.get_zones(file_system_type="cpfs")
        example_network = alicloud.vpc.Network("exampleNetwork",
            vpc_name="terraform-example",
            cidr_block="172.17.3.0/24")
        example_switch = alicloud.vpc.Switch("exampleSwitch",
            vswitch_name="terraform-example",
            cidr_block="172.17.3.0/24",
            vpc_id=example_network.id,
            zone_id=example_zones.zones[1].zone_id)
        example_file_system = alicloud.nas.FileSystem("exampleFileSystem",
            protocol_type="cpfs",
            storage_type="advance_200",
            file_system_type="cpfs",
            capacity=3600,
            description="terraform-example",
            zone_id=example_zones.zones[1].zone_id,
            vpc_id=example_network.id,
            vswitch_id=example_switch.id)
        example_fileset = alicloud.nas.Fileset("exampleFileset",
            file_system_id=example_file_system.id,
            description="terraform-example",
            file_system_path="/example_path/")
        ```

        ## Import

        Network Attached Storage (NAS) Fileset can be imported using the id, e.g.

        ```sh
         $ pulumi import alicloud:nas/fileset:Fileset example <file_system_id>:<fileset_id>
        ```

        :param str resource_name: The name of the resource.
        :param FilesetArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(FilesetArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 dry_run: Optional[pulumi.Input[bool]] = None,
                 file_system_id: Optional[pulumi.Input[str]] = None,
                 file_system_path: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = FilesetArgs.__new__(FilesetArgs)

            __props__.__dict__["description"] = description
            __props__.__dict__["dry_run"] = dry_run
            if file_system_id is None and not opts.urn:
                raise TypeError("Missing required property 'file_system_id'")
            __props__.__dict__["file_system_id"] = file_system_id
            if file_system_path is None and not opts.urn:
                raise TypeError("Missing required property 'file_system_path'")
            __props__.__dict__["file_system_path"] = file_system_path
            __props__.__dict__["fileset_id"] = None
            __props__.__dict__["status"] = None
        super(Fileset, __self__).__init__(
            'alicloud:nas/fileset:Fileset',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            description: Optional[pulumi.Input[str]] = None,
            dry_run: Optional[pulumi.Input[bool]] = None,
            file_system_id: Optional[pulumi.Input[str]] = None,
            file_system_path: Optional[pulumi.Input[str]] = None,
            fileset_id: Optional[pulumi.Input[str]] = None,
            status: Optional[pulumi.Input[str]] = None) -> 'Fileset':
        """
        Get an existing Fileset resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] description: The description of the Fileset. It must be `2` to `128` characters in length and must start with a letter or Chinese, but cannot start with `https://` or `https://`.
        :param pulumi.Input[bool] dry_run: The dry run.
        :param pulumi.Input[str] file_system_id: The ID of the file system.
        :param pulumi.Input[str] file_system_path: The path of the fileset.
        :param pulumi.Input[str] fileset_id: The first ID of the resource.
        :param pulumi.Input[str] status: The status of the fileset.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _FilesetState.__new__(_FilesetState)

        __props__.__dict__["description"] = description
        __props__.__dict__["dry_run"] = dry_run
        __props__.__dict__["file_system_id"] = file_system_id
        __props__.__dict__["file_system_path"] = file_system_path
        __props__.__dict__["fileset_id"] = fileset_id
        __props__.__dict__["status"] = status
        return Fileset(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[str]]:
        """
        The description of the Fileset. It must be `2` to `128` characters in length and must start with a letter or Chinese, but cannot start with `https://` or `https://`.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="dryRun")
    def dry_run(self) -> pulumi.Output[Optional[bool]]:
        """
        The dry run.
        """
        return pulumi.get(self, "dry_run")

    @property
    @pulumi.getter(name="fileSystemId")
    def file_system_id(self) -> pulumi.Output[str]:
        """
        The ID of the file system.
        """
        return pulumi.get(self, "file_system_id")

    @property
    @pulumi.getter(name="fileSystemPath")
    def file_system_path(self) -> pulumi.Output[str]:
        """
        The path of the fileset.
        """
        return pulumi.get(self, "file_system_path")

    @property
    @pulumi.getter(name="filesetId")
    def fileset_id(self) -> pulumi.Output[str]:
        """
        The first ID of the resource.
        """
        return pulumi.get(self, "fileset_id")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[str]:
        """
        The status of the fileset.
        """
        return pulumi.get(self, "status")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = ['ChartRepositoryArgs', 'ChartRepository']

@pulumi.input_type
class ChartRepositoryArgs:
    def __init__(__self__, *,
                 instance_id: pulumi.Input[str],
                 repo_name: pulumi.Input[str],
                 repo_namespace_name: pulumi.Input[str],
                 repo_type: Optional[pulumi.Input[str]] = None,
                 summary: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a ChartRepository resource.
        :param pulumi.Input[str] instance_id: The ID of the Container Registry instance.
        :param pulumi.Input[str] repo_name: The name of the repository that you want to create.
        :param pulumi.Input[str] repo_namespace_name: The namespace to which the repository belongs.
        :param pulumi.Input[str] repo_type: The default repository type. Valid values: `PUBLIC`,`PRIVATE`.
        :param pulumi.Input[str] summary: The summary about the repository.
        """
        pulumi.set(__self__, "instance_id", instance_id)
        pulumi.set(__self__, "repo_name", repo_name)
        pulumi.set(__self__, "repo_namespace_name", repo_namespace_name)
        if repo_type is not None:
            pulumi.set(__self__, "repo_type", repo_type)
        if summary is not None:
            pulumi.set(__self__, "summary", summary)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> pulumi.Input[str]:
        """
        The ID of the Container Registry instance.
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter(name="repoName")
    def repo_name(self) -> pulumi.Input[str]:
        """
        The name of the repository that you want to create.
        """
        return pulumi.get(self, "repo_name")

    @repo_name.setter
    def repo_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "repo_name", value)

    @property
    @pulumi.getter(name="repoNamespaceName")
    def repo_namespace_name(self) -> pulumi.Input[str]:
        """
        The namespace to which the repository belongs.
        """
        return pulumi.get(self, "repo_namespace_name")

    @repo_namespace_name.setter
    def repo_namespace_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "repo_namespace_name", value)

    @property
    @pulumi.getter(name="repoType")
    def repo_type(self) -> Optional[pulumi.Input[str]]:
        """
        The default repository type. Valid values: `PUBLIC`,`PRIVATE`.
        """
        return pulumi.get(self, "repo_type")

    @repo_type.setter
    def repo_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "repo_type", value)

    @property
    @pulumi.getter
    def summary(self) -> Optional[pulumi.Input[str]]:
        """
        The summary about the repository.
        """
        return pulumi.get(self, "summary")

    @summary.setter
    def summary(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "summary", value)


@pulumi.input_type
class _ChartRepositoryState:
    def __init__(__self__, *,
                 instance_id: Optional[pulumi.Input[str]] = None,
                 repo_name: Optional[pulumi.Input[str]] = None,
                 repo_namespace_name: Optional[pulumi.Input[str]] = None,
                 repo_type: Optional[pulumi.Input[str]] = None,
                 summary: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering ChartRepository resources.
        :param pulumi.Input[str] instance_id: The ID of the Container Registry instance.
        :param pulumi.Input[str] repo_name: The name of the repository that you want to create.
        :param pulumi.Input[str] repo_namespace_name: The namespace to which the repository belongs.
        :param pulumi.Input[str] repo_type: The default repository type. Valid values: `PUBLIC`,`PRIVATE`.
        :param pulumi.Input[str] summary: The summary about the repository.
        """
        if instance_id is not None:
            pulumi.set(__self__, "instance_id", instance_id)
        if repo_name is not None:
            pulumi.set(__self__, "repo_name", repo_name)
        if repo_namespace_name is not None:
            pulumi.set(__self__, "repo_namespace_name", repo_namespace_name)
        if repo_type is not None:
            pulumi.set(__self__, "repo_type", repo_type)
        if summary is not None:
            pulumi.set(__self__, "summary", summary)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the Container Registry instance.
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter(name="repoName")
    def repo_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the repository that you want to create.
        """
        return pulumi.get(self, "repo_name")

    @repo_name.setter
    def repo_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "repo_name", value)

    @property
    @pulumi.getter(name="repoNamespaceName")
    def repo_namespace_name(self) -> Optional[pulumi.Input[str]]:
        """
        The namespace to which the repository belongs.
        """
        return pulumi.get(self, "repo_namespace_name")

    @repo_namespace_name.setter
    def repo_namespace_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "repo_namespace_name", value)

    @property
    @pulumi.getter(name="repoType")
    def repo_type(self) -> Optional[pulumi.Input[str]]:
        """
        The default repository type. Valid values: `PUBLIC`,`PRIVATE`.
        """
        return pulumi.get(self, "repo_type")

    @repo_type.setter
    def repo_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "repo_type", value)

    @property
    @pulumi.getter
    def summary(self) -> Optional[pulumi.Input[str]]:
        """
        The summary about the repository.
        """
        return pulumi.get(self, "summary")

    @summary.setter
    def summary(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "summary", value)


class ChartRepository(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 instance_id: Optional[pulumi.Input[str]] = None,
                 repo_name: Optional[pulumi.Input[str]] = None,
                 repo_namespace_name: Optional[pulumi.Input[str]] = None,
                 repo_type: Optional[pulumi.Input[str]] = None,
                 summary: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a CR Chart Repository resource.

        For information about CR Chart Repository and how to use it, see [What is Chart Repository](https://www.alibabacloud.com/help/doc-detail/145318.htm).

        > **NOTE:** Available in v1.149.0+.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        default_registry_enterprise_instance = alicloud.cr.RegistryEnterpriseInstance("defaultRegistryEnterpriseInstance",
            payment_type="Subscription",
            period=1,
            instance_type="Advanced",
            instance_name="name")
        default_chart_namespace = alicloud.cr.ChartNamespace("defaultChartNamespace",
            instance_id=default_registry_enterprise_instance.id,
            namespace_name="name")
        default_chart_repository = alicloud.cr.ChartRepository("defaultChartRepository",
            repo_namespace_name=default_chart_namespace.namespace_name,
            instance_id=local["instance"],
            repo_name="repo_name")
        ```

        ## Import

        CR Chart Repository can be imported using the id, e.g.

        ```sh
         $ pulumi import alicloud:cr/chartRepository:ChartRepository example <instance_id>:<repo_namespace_name>:<repo_name>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] instance_id: The ID of the Container Registry instance.
        :param pulumi.Input[str] repo_name: The name of the repository that you want to create.
        :param pulumi.Input[str] repo_namespace_name: The namespace to which the repository belongs.
        :param pulumi.Input[str] repo_type: The default repository type. Valid values: `PUBLIC`,`PRIVATE`.
        :param pulumi.Input[str] summary: The summary about the repository.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ChartRepositoryArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a CR Chart Repository resource.

        For information about CR Chart Repository and how to use it, see [What is Chart Repository](https://www.alibabacloud.com/help/doc-detail/145318.htm).

        > **NOTE:** Available in v1.149.0+.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        default_registry_enterprise_instance = alicloud.cr.RegistryEnterpriseInstance("defaultRegistryEnterpriseInstance",
            payment_type="Subscription",
            period=1,
            instance_type="Advanced",
            instance_name="name")
        default_chart_namespace = alicloud.cr.ChartNamespace("defaultChartNamespace",
            instance_id=default_registry_enterprise_instance.id,
            namespace_name="name")
        default_chart_repository = alicloud.cr.ChartRepository("defaultChartRepository",
            repo_namespace_name=default_chart_namespace.namespace_name,
            instance_id=local["instance"],
            repo_name="repo_name")
        ```

        ## Import

        CR Chart Repository can be imported using the id, e.g.

        ```sh
         $ pulumi import alicloud:cr/chartRepository:ChartRepository example <instance_id>:<repo_namespace_name>:<repo_name>
        ```

        :param str resource_name: The name of the resource.
        :param ChartRepositoryArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ChartRepositoryArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 instance_id: Optional[pulumi.Input[str]] = None,
                 repo_name: Optional[pulumi.Input[str]] = None,
                 repo_namespace_name: Optional[pulumi.Input[str]] = None,
                 repo_type: Optional[pulumi.Input[str]] = None,
                 summary: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ChartRepositoryArgs.__new__(ChartRepositoryArgs)

            if instance_id is None and not opts.urn:
                raise TypeError("Missing required property 'instance_id'")
            __props__.__dict__["instance_id"] = instance_id
            if repo_name is None and not opts.urn:
                raise TypeError("Missing required property 'repo_name'")
            __props__.__dict__["repo_name"] = repo_name
            if repo_namespace_name is None and not opts.urn:
                raise TypeError("Missing required property 'repo_namespace_name'")
            __props__.__dict__["repo_namespace_name"] = repo_namespace_name
            __props__.__dict__["repo_type"] = repo_type
            __props__.__dict__["summary"] = summary
        super(ChartRepository, __self__).__init__(
            'alicloud:cr/chartRepository:ChartRepository',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            instance_id: Optional[pulumi.Input[str]] = None,
            repo_name: Optional[pulumi.Input[str]] = None,
            repo_namespace_name: Optional[pulumi.Input[str]] = None,
            repo_type: Optional[pulumi.Input[str]] = None,
            summary: Optional[pulumi.Input[str]] = None) -> 'ChartRepository':
        """
        Get an existing ChartRepository resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] instance_id: The ID of the Container Registry instance.
        :param pulumi.Input[str] repo_name: The name of the repository that you want to create.
        :param pulumi.Input[str] repo_namespace_name: The namespace to which the repository belongs.
        :param pulumi.Input[str] repo_type: The default repository type. Valid values: `PUBLIC`,`PRIVATE`.
        :param pulumi.Input[str] summary: The summary about the repository.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ChartRepositoryState.__new__(_ChartRepositoryState)

        __props__.__dict__["instance_id"] = instance_id
        __props__.__dict__["repo_name"] = repo_name
        __props__.__dict__["repo_namespace_name"] = repo_namespace_name
        __props__.__dict__["repo_type"] = repo_type
        __props__.__dict__["summary"] = summary
        return ChartRepository(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> pulumi.Output[str]:
        """
        The ID of the Container Registry instance.
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="repoName")
    def repo_name(self) -> pulumi.Output[str]:
        """
        The name of the repository that you want to create.
        """
        return pulumi.get(self, "repo_name")

    @property
    @pulumi.getter(name="repoNamespaceName")
    def repo_namespace_name(self) -> pulumi.Output[str]:
        """
        The namespace to which the repository belongs.
        """
        return pulumi.get(self, "repo_namespace_name")

    @property
    @pulumi.getter(name="repoType")
    def repo_type(self) -> pulumi.Output[str]:
        """
        The default repository type. Valid values: `PUBLIC`,`PRIVATE`.
        """
        return pulumi.get(self, "repo_type")

    @property
    @pulumi.getter
    def summary(self) -> pulumi.Output[Optional[str]]:
        """
        The summary about the repository.
        """
        return pulumi.get(self, "summary")

